#!/usr/bin/python3

# this script is carefully crafted in order to operate with any python
# version >= 2.7, and should work/be adoptable for any PyQt version
#
# usage: python{2,3} pyqtver.py [3|4|5]

import sys
import importlib

try:
    qtver = sys.argv[1]
except IndexError:
    qtver = "5"

qtdict = {
    # version: qtlib, pyqtlib
    "3": ("qt", "qt"),
    "4": ("PyQt4.QtCore", "PyQt4.QtCore"),
    "5": ("PyQt5.QtCore", "PyQt5.Qt"),
}

def pr(s, *args, **kwargs):
    print(s.format(*args, **kwargs))

pr("Python: {}", sys.version.split()[0])

# sip version
try:
    import sip
except ImportError:
    pr("sip: n/a # sip not installed, too old or damaged installation")
else:
    pr("Sip: {}", sip.SIP_VERSION_STR)
    # qt and pyqt versions
    try:
        qt, pyqt = qtdict[qtver]
    except KeyError:
        pr("Qt version {qtver} not supported, fix script", **locals())
    else:
        try:
            qtlib = importlib.import_module(qt)
        except ImportError:
            pr("PyQt: n/a # import {qt} failed, PyQt{qtver} not installed", **locals())
        else:
            try:
                pyqtlib = importlib.import_module(pyqt)
            except ImportError:
                pr("PyQt: n/a # import {pyqt} failed, PyQt{qtver} not installed", **locals())
            else:
                pr("Qt: {}", qtlib.QT_VERSION_STR)
                pr("PyQt: {}", pyqtlib.PYQT_VERSION_STR)
